@@ -101,6 +101,9 @@ INVALIDPARAMETER_ACLTYPEMISMATCH = 'InvalidParameter.AclTypeMismatch'
 # 参数不支持同时指定。
 INVALIDPARAMETER_COEXIST = 'InvalidParameter.Coexist'
 
+# 指定的两个参数冲突，不能同时存在。
+INVALIDPARAMETER_CONFLICT = 'InvalidParameter.Conflict'
+
 # 当前IP已在其他公网IP类型的流量镜像中使用。
 INVALIDPARAMETER_DUPLICATEDLBTRAFFICMIRRORCOLLECTORS = 'InvalidParameter.DuplicatedLbTrafficMirrorCollectors'
 
@@ -209,6 +212,9 @@ INVALIDPARAMETERVALUE_BANDWIDTHTOOSMALL = 'InvalidParameterValue.BandwidthTooSma
 # 指定云联网关联黑石私有网络数量达到上限。
 INVALIDPARAMETERVALUE_CCNATTACHBMVPCLIMITEXCEEDED = 'InvalidParameterValue.CcnAttachBmvpcLimitExceeded'
 
+# 指定CIDR存在重叠。
+INVALIDPARAMETERVALUE_CIDRCONFLICT = 'InvalidParameterValue.CidrConflict'
+
 # 目的网段不在对端VPC的CIDR范围内。
 INVALIDPARAMETERVALUE_CIDRNOTINPEERVPC = 'InvalidParameterValue.CidrNotInPeerVpc'
 
@@ -263,6 +269,9 @@ INVALIDPARAMETERVALUE_INCONSISTENTINSTANCEINTERNETCHARGETYPE = 'InvalidParameter
 # 该实例不支持AnycastEIP。
 INVALIDPARAMETERVALUE_INSTANCEDOESNOTSUPPORTANYCAST = 'InvalidParameterValue.InstanceDoesNotSupportAnycast'
 
+# 实例不支持在网卡上显示EIP。支持的实例ID格式为 ins-xxxxxxxx 和 eks-xxxxxxxx
+INVALIDPARAMETERVALUE_INSTANCEDOESNOTSUPPORTEIPVISIBLEONENI = 'InvalidParameterValue.InstanceDoesNotSupportEipVisibleOnEni'
+
 # 实例不存在公网IP。
 INVALIDPARAMETERVALUE_INSTANCEHASNOWANIP = 'InvalidParameterValue.InstanceHasNoWanIP'
 
@@ -284,9 +293,15 @@ INVALIDPARAMETERVALUE_INSTANCENORMALPUBLICIPBLOCKED = 'InvalidParameterValue.Ins
 # 弹性网卡绑定的实例与地址绑定的实例不一致。
 INVALIDPARAMETERVALUE_INSTANCENOTMATCHASSOCIATEENI = 'InvalidParameterValue.InstanceNotMatchAssociateEni'
 
+# 实例所属的VPC不支持在网卡上显示EIP
+INVALIDPARAMETERVALUE_INSTANCEVPCDOESNOTSUPPORTEIPVISIBLEONENI = 'InvalidParameterValue.InstanceVpcDoesNotSupportEipVisibleOnEni'
+
 # 网络计费模式没有更改。
 INVALIDPARAMETERVALUE_INTERNETCHARGETYPENOTCHANGED = 'InvalidParameterValue.InternetChargeTypeNotChanged'
 
+# 参数非法
+INVALIDPARAMETERVALUE_INVALID = 'InvalidParameterValue.Invalid'
+
 # 无效的带宽包计费方式。
 INVALIDPARAMETERVALUE_INVALIDBANDWIDTHPACKAGECHARGETYPE = 'InvalidParameterValue.InvalidBandwidthPackageChargeType'
 
@@ -386,6 +401,9 @@ INVALIDPARAMETERVALUE_NETDETECTSAMEIP = 'InvalidParameterValue.NetDetectSameIp'
 # 网络接口ID不正确。
 INVALIDPARAMETERVALUE_NETWORKINTERFACEIDMALFORMED = 'InvalidParameterValue.NetworkInterfaceIdMalformed'
 
+# 指定的弹性公网IP地址已绑定到网卡 ，不支持绑定到不同的网卡。
+INVALIDPARAMETERVALUE_NETWORKINTERFACEIDNOTMATCH = 'InvalidParameterValue.NetworkInterfaceIdNotMatch'
+
 # 网卡所绑定实例不支持绑定弹性公网IPv6
 INVALIDPARAMETERVALUE_NETWORKINTERFACEINSTANCENOTSUPPORT = 'InvalidParameterValue.NetworkInterfaceInstanceNotSupport'
 
@@ -410,6 +428,12 @@ INVALIDPARAMETERVALUE_ONLYSUPPORTEDFORMASTERNETWORKCARD = 'InvalidParameterValue
 # 参数值格式不匹配。
 INVALIDPARAMETERVALUE_PARAMETERMISMATCH = 'InvalidParameterValue.ParameterMismatch'
 
+# 私网IP是一个辅助IP，不支持其绑定的EIP在网卡上显示
+INVALIDPARAMETERVALUE_PRIVATEIPADDRESSDOESNOTSUPPORTEIPVISIBLEONENI = 'InvalidParameterValue.PrivateIpAddressDoesNotSupportEipVisibleOnEni'
+
+# 指定的弹性公网IP地址已绑定到私有IP地址，不支持绑定到不同的私有IP地址。
+INVALIDPARAMETERVALUE_PRIVATEIPADDRESSNOTMATCH = 'InvalidParameterValue.PrivateIpAddressNotMatch'
+
 # 私网NAT网关不存在
 INVALIDPARAMETERVALUE_PRIVATENATNOTEXISTS = 'InvalidParameterValue.PrivateNatNotExists'
 
@@ -740,6 +764,9 @@ OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
 # 互斥的任务正在执行。
 OPERATIONDENIED_MUTEXTASKRUNNING = 'OperationDenied.MutexTaskRunning'
 
+# 请求的次数超过了频率限制。
+REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
+
 # 资源被占用。
 RESOURCEINUSE = 'ResourceInUse'
 
@@ -878,6 +905,12 @@ UNSUPPORTEDOPERATION_CCNHASFLOWLOG = 'UnsupportedOperation.CcnHasFlowLog'
 # CCN实例所属账号未通过联通审批。
 UNSUPPORTEDOPERATION_CCNINSTANCEACCOUNTNOTAPPROVEDBYUNICOM = 'UnsupportedOperation.CcnInstanceAccountNotApprovedByUnicom'
 
+# 云联网关联实例绑定了策略路由下一跳，不允许解关联，需要先解绑策略路由下一跳
+UNSUPPORTEDOPERATION_CCNINSTANCEHASBOUNDPOLICYROUTENEXTHOPNOTALLOWEDDETACH = 'UnsupportedOperation.CcnInstanceHasBoundPolicyRouteNextHopNotAllowedDetach'
+
+# 云联网关联实例绑定了策略路由规则，不允许解关联，需要先解绑策略路由规则
+UNSUPPORTEDOPERATION_CCNINSTANCEHASBOUNDPOLICYROUTERULENOTALLOWEDDETACH = 'UnsupportedOperation.CcnInstanceHasBoundPolicyRouteRuleNotAllowedDetach'
+
 # 云联网开启ipv6不支持创建多路由表
 UNSUPPORTEDOPERATION_CCNIPV6NOTSUPPORTMULTIPLEROUTETABLE = 'UnsupportedOperation.CcnIpv6NotSupportMultipleRouteTable'
 
@@ -1127,6 +1160,18 @@ UNSUPPORTEDOPERATION_NATGATEWAYEIPNOTEXISTS = 'UnsupportedOperation.NatGatewayEi
 # NAT网关存在未解绑的IP。
 UNSUPPORTEDOPERATION_NATGATEWAYHADEIPUNASSOCIATE = 'UnsupportedOperation.NatGatewayHadEipUnassociate'
 
+# NAT网关最近流量“出/入带宽”峰值取大超过检测带宽阈值。
+UNSUPPORTEDOPERATION_NATGATEWAYHAVEHIGHTRAFFIC = 'UnsupportedOperation.NatGatewayHaveHighTraffic'
+
+# NAT网关存在路由。
+UNSUPPORTEDOPERATION_NATGATEWAYHAVEROUTE = 'UnsupportedOperation.NatGatewayHaveRoute'
+
+# NAT网关存在路由和最近流量“出/入带宽”峰值取大超过检测带宽阈值。
+UNSUPPORTEDOPERATION_NATGATEWAYHAVEROUTEANDHIGHTRAFFIC = 'UnsupportedOperation.NatGatewayHaveRouteAndHighTraffic'
+
+# NAT实例当前负载较高，请稍后重试
+UNSUPPORTEDOPERATION_NATGATEWAYISBUSY = 'UnsupportedOperation.NatGatewayIsBusy'
+
 # NAT网关已被封禁，不支持此操作。
 UNSUPPORTEDOPERATION_NATGATEWAYRESTRICTED = 'UnsupportedOperation.NatGatewayRestricted'
 
@@ -1142,9 +1187,33 @@ UNSUPPORTEDOPERATION_NATGATEWAYSNATRULENOTEXISTS = 'UnsupportedOperation.NatGate
 # NAT网关类型不支持SNAT规则。
 UNSUPPORTEDOPERATION_NATGATEWAYTYPENOTSUPPORTSNAT = 'UnsupportedOperation.NatGatewayTypeNotSupportSNAT'
 
+# NAT网关绑定了vpg，不支持该操作。
+UNSUPPORTEDOPERATION_NATHASBOUNDVPG = 'UnsupportedOperation.NatHasBoundVpg'
+
+# NAT网关开启了ECMP，不支持该操作。
+UNSUPPORTEDOPERATION_NATHASECMP = 'UnsupportedOperation.NatHasECMP'
+
+# NAT网关开启了网关流控，不支持该操作。
+UNSUPPORTEDOPERATION_NATHASENABLEDGATEWAYFLOWCONTROL = 'UnsupportedOperation.NatHasEnabledGatewayFlowControl'
+
+# NAT网关开启了流日志，不支持该操作。
+UNSUPPORTEDOPERATION_NATHASFLOWLOG = 'UnsupportedOperation.NatHasFlowLog'
+
+# 独享型NAT不支持该操作。
+UNSUPPORTEDOPERATION_NATINSTANCEEXCLUSIVE = 'UnsupportedOperation.NatInstanceExclusive'
+
 # NAT实例不支持该操作。
 UNSUPPORTEDOPERATION_NATNOTSUPPORTED = 'UnsupportedOperation.NatNotSupported'
 
+# NAT网关规格超过标准型nat规格，不支持该操作。
+UNSUPPORTEDOPERATION_NATSPECIFICATIONEXCEEDED = 'UnsupportedOperation.NatSpecificationExceeded'
+
+# NAT网关实例类型不支持该操作。
+UNSUPPORTEDOPERATION_NATTYPEERROR = 'UnsupportedOperation.NatTypeError'
+
+# NAT网关近30天的最大用量超过标准型NAT规格，不支持该操作。
+UNSUPPORTEDOPERATION_NATUSAGEEXCEEDED = 'UnsupportedOperation.NatUsageExceeded'
+
 # 没有CDC专线网关。
 UNSUPPORTEDOPERATION_NOCDCDCGW = 'UnsupportedOperation.NoCdcDcGw'
 
@@ -1184,6 +1253,9 @@ UNSUPPORTEDOPERATION_NOTSUPPORTDELETEVPCBMPEER = 'UnsupportedOperation.NotSuppor
 # 默认路由表，不支持修改。
 UNSUPPORTEDOPERATION_NOTSUPPORTMODIFYDEFAULTCCNROUTETABLE = 'UnsupportedOperation.NotSupportModifyDefaultCcnRouteTable'
 
+# 不支持的自定义路由类型。
+UNSUPPORTEDOPERATION_NOTSUPPORTROUTETYPE = 'UnsupportedOperation.NotSupportRouteType'
+
 # 不支持编辑相同的实例和源地址。
 UNSUPPORTEDOPERATION_NOTSUPPORTSAMECCNINSTANCEANDSOURCEADDRESS = 'UnsupportedOperation.NotSupportSameCcnInstanceAndSourceAddress'
 
@@ -1394,6 +1466,12 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDBINDLOCALZONEEIP = 'UnsupportedOperation.Unsuppo
 # 指定机型不支持弹性网卡。
 UNSUPPORTEDOPERATION_UNSUPPORTEDINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedInstanceFamily'
 
+# 传统型账号不支持该操作。
+UNSUPPORTEDOPERATION_UNSUPPORTEDLEGACYACCOUNT = 'UnsupportedOperation.UnsupportedLegacyAccount'
+
+# NAT网关部署在local zone，不支持该操作。
+UNSUPPORTEDOPERATION_UNSUPPORTEDLOCALZONENAT = 'UnsupportedOperation.UnsupportedLocalZoneNat'
+
 # 暂无法在此国家/地区提供该服务。
 UNSUPPORTEDOPERATION_UNSUPPORTEDREGION = 'UnsupportedOperation.UnsupportedRegion'
 
@@ -1403,6 +1481,9 @@ UNSUPPORTEDOPERATION_USERANDCCNCHARGETYPENOTMATCH = 'UnsupportedOperation.UserAn
 # 指定安全组规则版本号和当前最新版本不一致。
 UNSUPPORTEDOPERATION_VERSIONMISMATCH = 'UnsupportedOperation.VersionMismatch'
 
+# 当前VPN版本小于4.0，不支持该操作。
+UNSUPPORTEDOPERATION_VERSIONNOTSUPPORTED = 'UnsupportedOperation.VersionNotSupported'
+
 # 资源不属于同一个VPC。
 UNSUPPORTEDOPERATION_VPCMISMATCH = 'UnsupportedOperation.VpcMismatch'
 
